@@ -7,11 +7,12 @@ prismedia - tool to upload videos to Peertube and Youtube
 Usage:
   prismedia --file=<FILE> [options]
   prismedia -f <FILE> --tags=STRING [options]
+  prismedia --hearthbeat
   prismedia -h | --help
   prismedia --version
 
 Options:
-  -f, --file=STRING Path to the video file to upload in mp4. This is the only mandatory option.
+  -f, --file=STRING Path to the video file to upload. This is the only mandatory option.
   --name=NAME  Name of the video to upload. (default to video filename)
   -d, --description=STRING  Description of the video. (default: default description)
   -t, --tags=STRING  Tags for the video. comma separated.
@@ -39,8 +40,7 @@ Options:
                         DATE should be in the past
   --auto-originalDate     Automatically use the file modification time as original date
   --thumbnail=STRING    Path to a file to use as a thumbnail for the video.
-                        Supported types are jpg and jpeg.
-                        By default, prismedia search for an image based on video name followed by .jpg or .jpeg
+                        By default, prismedia search for an image based on video name followed by .jpg, .jpeg or .png
   --channel=STRING Set the channel to use for the video (Peertube only)
                     If the channel is not found, spawn an error except if --channelCreate is set.
   --channelCreate  Create the channel if not exists. (Peertube only, default do not create)
@@ -50,6 +50,9 @@ Options:
   --playlistCreate  Create the playlist if not exists. (default do not create)
                     Only relevant if --playlist is set.
   --progress=STRING Set the progress bar view, one of percentage, bigFile (MB), accurate (KB).
+
+  --hearthbeat  Use some credits to show some activity for you apikey so the platform know it is used and would not put your quota to 0 (only Youtube currently)
+
   -h --help  Show this help.
   --version  Show version.
 
@@ -106,12 +109,6 @@ import os
 import datetime
 import logging
 logger = logging.getLogger('Prismedia')
-logger.setLevel(logging.INFO)
-ch = logging.StreamHandler()
-ch.setLevel(logging.INFO)
-formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s: %(message)s')
-ch.setFormatter(formatter)
-logger.addHandler(ch)
 
 from docopt import docopt
 
@@ -127,16 +124,8 @@ except ImportError:
                   ' is installed: \n'
                   'see https://github.com/halst/schema\n')
     exit(1)
-try:
-    # noinspection PyUnresolvedReferences
-    import magic
-except ImportError:
-    logger.critical('This program requires that the `python-magic` library'
-                  ' is installed, NOT the Python bindings to libmagic API \n'
-                  'see https://github.com/ahupp/python-magic\n')
-    exit(1)
 
-VERSION = "prismedia v0.11.0"
+VERSION = "prismedia v0.12.0"
 
 VALID_PRIVACY_STATUSES = ('public', 'private', 'unlisted')
 VALID_CATEGORIES = (
@@ -154,20 +143,6 @@ VALID_LANGUAGES = ('arabic', 'english', 'french',
 VALID_PROGRESS = ('percentage', 'bigfile', 'accurate')
 
 
-def validateVideo(path):
-    supported_types = ['video/mp4']
-    detected_type = magic.from_file(path, mime=True)
-    if detected_type not in supported_types:
-        print("File", path, "detected type is", detected_type, "which is not one of", supported_types)
-
-        force_file = ['y', 'yes']
-        is_forcing = input("Are you sure you selected the correct file? (y/N)")
-        if is_forcing.lower() not in force_file:
-            return False
-
-    return path
-
-
 def validateCategory(category):
     if category.lower() in VALID_CATEGORIES:
         return True
@@ -221,15 +196,6 @@ def validateOriginalDate(originalDate):
     return True
 
 
-def validateThumbnail(thumbnail):
-    supported_types = ['image/jpg', 'image/jpeg']
-    if os.path.exists(thumbnail) and \
-            magic.from_file(thumbnail, mime=True) in supported_types:
-        return thumbnail
-    else:
-        return False
-
-
 def validateLogLevel(loglevel):
     numeric_level = getattr(logging, loglevel, None)
     if not isinstance(numeric_level, int):
@@ -318,7 +284,7 @@ def main():
     })
 
     schema = Schema({
-        '--file': And(str, os.path.exists, validateVideo, error='file is not supported, please use mp4'),
+        '--file': And(str, os.path.exists, error='file does not exists, please check path'),
         # Strict option checks - at the moment Schema needs to check Hook and Optional separately #
         Hook('--name', handler=_optionnalOrStrict): object,
         Hook('--description', handler=_optionnalOrStrict): object,
@@ -389,18 +355,24 @@ def main():
         Optional('--disable-comments'): bool,
         Optional('--nsfw'): bool,
         Optional('--thumbnail'): Or(None, And(
-                                    str, validateThumbnail, error='thumbnail is not supported, please use jpg/jpeg'),
+                                    str, os.path.exists, error='Thumbnail does not exists, please check the path.'),
                                     ),
         Optional('--channel'): Or(None, str),
         Optional('--channelCreate'): bool,
         Optional('--playlist'): Or(None, str),
         Optional('--playlistCreate'): bool,
         Optional('--progress'): Or(None, And(str, validateProgress, error="Sorry, progress visualisation not supported")),
+        '--hearthbeat': bool,
         '--help': bool,
         '--version': bool,
         # This allow to return all other options for further use: https://github.com/keleshev/schema#extra-keys
         object: object
     })
+
+    if options.get('--hearthbeat'):
+        yt_upload.hearthbeat()
+        exit(0)
+
     # We need to validate early options first as withNFO and logs options should be prioritized
     try:
         options = earlyoptionSchema.validate(options)
