@@ -100,6 +100,15 @@ def getLanguage(language, platform):
         return PEERTUBE_LANGUAGE[language.lower()]
 
 
+def ask_overwrite(question):
+    while True:
+        reply = str(input(question + ' (Yes/[No]): ') or "No").lower().strip()
+        if reply[:1] == 'y':
+            return True
+        if reply[:1] == 'n':
+            return False
+
+
 def remove_empty_kwargs(**kwargs):
     good_kwargs = {}
     if kwargs is not None:
@@ -117,6 +126,8 @@ def searchThumbnail(options):
             options['--thumbnail'] = video_directory + options.get('--name') + ".jpg"
         elif isfile(video_directory + options.get('--name') + ".jpeg"):
             options['--thumbnail'] = video_directory + options.get('--name') + ".jpeg"
+        elif isfile(video_directory + options.get('--name') + ".png"):
+            options['--thumbnail'] = video_directory + options.get('--name') + ".png"
     # Then, if we still not have thumbnail, check for thumbnail based on videofile name
     if not options.get('--thumbnail'):
         video_file = splitext(basename(options.get('--file')))[0]
@@ -124,6 +135,8 @@ def searchThumbnail(options):
             options['--thumbnail'] = video_directory + video_file + ".jpg"
         elif isfile(video_directory + video_file + ".jpeg"):
             options['--thumbnail'] = video_directory + video_file + ".jpeg"
+        elif isfile(video_directory + video_file + ".png"):
+            options['--thumbnail'] = video_directory + video_file + ".png"
 
     # Display some info after research
     if not options.get('--thumbnail'):
